@@ -46,7 +46,19 @@ def def_pwd(path):
 
 class Call(object):
     """
-    Call file in paths
+    Call file in paths.
+
+    When there are four files in pwd path:
+        (file1.csv, file2.csv, file3.txt, file4.png)
+
+    Examples
+    ---------
+    >>> call = Call(".",backend="csv")
+    >>> file1 = call.file1
+    >>> file2 = call.file2
+    >>> call = Call(".",backend="txt")
+    >>> file = call.file3
+
     """
 
     @staticmethod
@@ -75,7 +87,7 @@ class Call(object):
         backend:str
             default imported type to show
         prefix_with_upper:str
-            prefix_with_upper for all file add to file in this code to excape same name
+            prefix_with_upper for all file add to file in this code to escape same name
         index_col:
             use the first column as index in table.
         """
@@ -222,7 +234,7 @@ class Call(object):
         spath
         """
         if name in self.__extension__:
-            return self.__class__(*self._paths, backend=name, prefix=self._prefix)
+            return self.__class__(*self._paths, backend=name, prefix_with_upper=self._prefix)
         else:
             raise AttributeError("'%s' object has no attribute '%s'" % (self.__class__.__name__, name))
 
@@ -256,6 +268,21 @@ def check_file(spath, file_path, suffix=None):
 class BatchFile:
     """
     Search files and filter files and re-site files.
+
+    Examples
+    ---------
+    >>> a = BatchFile(".")
+    >>> a.filter_dir_name("a")
+    >>> a.filter_file_name("2")
+    >>> print(a.file_list)
+    ...
+    #copy the file to new path and keep the dir structure
+    >>> a.to_path(r"C:\Users\Admin\Desktop\d2",flatten=False)
+    #copy the file to new path, flatten the file and add the dir name on file: dirname_1_filename.
+    >>> a.to_path(r"C:\Users\Admin\Desktop\d2", add_dir=[-1], flatten=True)
+    #copy the file to new path, flatten the file and add the dir name on file: dirname_2_dirname_1_filename.
+    >>> a.to_path(r"C:\Users\Admin\Desktop\d2", add_dir=[-2,-1], flatten=True)
+
     """
 
     def __init__(self, path=None, suffix=None):
@@ -453,14 +480,14 @@ class BatchFile:
             shutil.copy(i, j)
 
 
-if __name__ == "__main__":
+# if __name__ == "__main__":
     # others please use shutil
     # shutil.copytree()
     # a = BatchFile(r"C:\Users\wangchangxin\Desktop\d1")
     # a.filter_dir_name("a", layer=-1)
     # a.filter_file_name("2")
     # a.to_path(r"C:\Users\wangchangxin\Desktop\d2", add_dir=[-2, -1], flatten=True)
-    bf = BatchFile(r"/home/iap13/wcx/CHG")
+    # bf = BatchFile(r"/home/iap13/wcx/CHG")
 
     # bf.filter_dir_name(includ="Mo")
-    filenames = bf.file_list
\ No newline at end of file
+    # filenames = bf.file_list
\ No newline at end of file
