@@ -17,6 +17,7 @@ import time
 from collections.abc import Iterable
 from functools import partial, wraps
 from itertools import chain
+from multiprocessing import Pool
 from sys import getsizeof
 
 import numpy as np
@@ -27,9 +28,18 @@ from tqdm import tqdm
 
 def time_this_function(func):
     """
-    time the function.
+    Time the function.
     use as a decorator.
 
+    Examples
+    ---------
+    ::
+        @time_this_function
+
+        def func(x):
+            return x
+        a= func(1)
+
     Parameters
     ----------
     func: Callable
@@ -81,11 +91,18 @@ def check_random_state(seed):
                      ' instance' % seed)
 
 
-def parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_size='auto', store=None, **kwargs):
+def parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_size='auto', store=None, mode="j", **kwargs):
     """
 
     Parallelize the function for iterable.
 
+    Examples
+    ----------
+    >>> def func(x):
+    >>>     return x**2
+    >>> result = parallelize(n_jobs=2,func=func,iterable=[1,2,3,4,5])
+    [1,2,3,4,5]
+
     Note:
         For "large" calculated function, with small return for each function.
 
@@ -119,6 +136,9 @@ def parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_size='a
         Not been used.
         store or not, if store, the result would be store to disk and return nothing.
 
+    mode:
+        "j":"joblib" or "m":"multiprocessing"
+
     Returns
     -------
     results
@@ -126,13 +146,19 @@ def parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_size='a
 
     """
     _ = store
-
     func = partial(func, **kwargs)
+
+    if mode == "m":
+        with Pool(n_jobs) as p:
+            ret = p.map(func, iterable)
+        return ret
+
     if effective_n_jobs(n_jobs) == 1:
         parallel, func = list, func
     else:
         parallel = Parallel(n_jobs=n_jobs, batch_size=batch_size)
         func = delayed(func)
+
     if tq:
         if respective:
             return parallel(func(*iter_i) for iter_i in tqdm(iterable))
@@ -145,12 +171,20 @@ def parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_size='a
             return parallel(func(iter_i) for iter_i in iterable)
 
 
-def batch_parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_size: int = 1000, store=None, **kwargs):
+def batch_parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_size: int = 1000, store=None, mode="j",
+                      **kwargs):
     """
     Parallelize the function for iterable.
 
     The iterable would be batched into batch_size  for less resources transmission.
 
+    Examples
+    ----------
+    >>> def func(x):
+    >>>     return x**2
+    >>> result = parallelize(n_jobs=2,func=func,iterable=[1,2,3,4,5])
+    [1,2,3,4,5]
+
     Note:
     For "small" calculated function, with small return for each function.
 
@@ -176,6 +210,8 @@ def batch_parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_s
         function to calculate
     iterable:
         iterable object
+    mode:
+        "j":"joblib" or "m":"multiprocessing"
     kwargs:
         kwargs for function
     store:bool,None
@@ -217,6 +253,13 @@ def batch_parallelize(n_jobs, func, iterable, respective=False, tq=True, batch_s
 
     parallel = Parallel(n_jobs=n_jobs, batch_size=batch_size)
 
+    if mode == "m":
+        with Pool(n_jobs) as p:
+            y = p.map(func_batch_re, iterables)
+        ret = []
+        [ret.extend(i) for i in y]
+        return ret
+
     if respective:
         func_batch = delayed(func_batch_re)
     else:
@@ -450,9 +493,15 @@ class TTClass(_TTClass):
     """
     quick time.
     use tt object.
-    >>>tt.t
-    >>>#tt.t
-    >>>tt.p
+
+    Examples:
+    -----------
+    >>> tt.t
+    >>> a=4
+    >>> tt.t
+    >>> tt.p
+    [['t1-t0:' ****]]
+
     """
 
     def __init__(self, **kwargs):
@@ -475,20 +524,30 @@ class TTClass(_TTClass):
 tt = TTClass()
 
 if __name__ == "__main__":
-    def func(n,_=None):
+    def func(n, _=None):
         # time.sleep(0.0001)
         s = np.random.random((100, 50))
         return s
 
+
     iterable = np.arange(10000)
     iterable2 = np.arange(20000)
     tt.t
-    s = parallelize(1, func, zip(iterable,iterable), respective=True, tq=True, batch_size=1000)
+    s = parallelize(1, func, zip(iterable, iterable), respective=True, tq=True, batch_size=1000)
     tt.t
     s = parallelize(1, func, iterable, respective=False, tq=True, batch_size=1000)
     tt.t
     s = batch_parallelize(1, func, zip(iterable, iterable), respective=True, tq=True, batch_size=1000, store=False)
     tt.t
     s = batch_parallelize(1, func, iterable, respective=False, tq=True, batch_size=1000, store=False)
+
+    tt.t
+    s = parallelize(1, func, zip(iterable, iterable), respective=True, tq=True, batch_size=1000,mode="m")
+    tt.t
+    s = parallelize(1, func, iterable, respective=False, tq=True, batch_size=1000,mode="m")
+    tt.t
+    s = batch_parallelize(1, func, zip(iterable, iterable), respective=True, tq=True, batch_size=1000, store=False,mode="m")
+    tt.t
+    s = batch_parallelize(1, func, iterable, respective=False, tq=True, batch_size=1000, store=False,mode="m")
     tt.t
     tt.p
